# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from faucetconfrpc import faucetconfrpc_pb2 as faucetconfrpc_dot_faucetconfrpc__pb2


class FaucetConfServerStub(object):
    """NOTE: currently some of these API calls allow specifying an optional config_file.
    This will be removed in future so the client does not need/have knowledge of the underlying YAML store.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetConfigFile = channel.unary_unary(
                '/faucetconfserver.FaucetConfServer/GetConfigFile',
                request_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.GetConfigFileRequest.SerializeToString,
                response_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.GetConfigFileReply.FromString,
                )
        self.SetConfigFile = channel.unary_unary(
                '/faucetconfserver.FaucetConfServer/SetConfigFile',
                request_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.SetConfigFileRequest.SerializeToString,
                response_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.SetConfigFileReply.FromString,
                )
        self.DelConfigFromFile = channel.unary_unary(
                '/faucetconfserver.FaucetConfServer/DelConfigFromFile',
                request_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.DelConfigFromFileRequest.SerializeToString,
                response_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.DelConfigFromFileReply.FromString,
                )
        self.AddPortMirror = channel.unary_unary(
                '/faucetconfserver.FaucetConfServer/AddPortMirror',
                request_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.AddPortMirrorRequest.SerializeToString,
                response_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.AddPortMirrorReply.FromString,
                )
        self.RemovePortMirror = channel.unary_unary(
                '/faucetconfserver.FaucetConfServer/RemovePortMirror',
                request_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.RemovePortMirrorRequest.SerializeToString,
                response_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.RemovePortMirrorReply.FromString,
                )
        self.ClearPortMirror = channel.unary_unary(
                '/faucetconfserver.FaucetConfServer/ClearPortMirror',
                request_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.ClearPortMirrorRequest.SerializeToString,
                response_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.ClearPortMirrorReply.FromString,
                )
        self.AddPortAcl = channel.unary_unary(
                '/faucetconfserver.FaucetConfServer/AddPortAcl',
                request_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.AddPortAclRequest.SerializeToString,
                response_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.AddPortAclReply.FromString,
                )
        self.RemovePortAcl = channel.unary_unary(
                '/faucetconfserver.FaucetConfServer/RemovePortAcl',
                request_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.RemovePortAclRequest.SerializeToString,
                response_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.RemovePortAclReply.FromString,
                )
        self.SetPortAcl = channel.unary_unary(
                '/faucetconfserver.FaucetConfServer/SetPortAcl',
                request_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.SetPortAclRequest.SerializeToString,
                response_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.SetPortAclReply.FromString,
                )
        self.SetDpInterfaces = channel.unary_unary(
                '/faucetconfserver.FaucetConfServer/SetDpInterfaces',
                request_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.SetDpInterfacesRequest.SerializeToString,
                response_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.SetDpInterfacesReply.FromString,
                )
        self.GetDpInfo = channel.unary_unary(
                '/faucetconfserver.FaucetConfServer/GetDpInfo',
                request_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.GetDpInfoRequest.SerializeToString,
                response_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.GetDpInfoReply.FromString,
                )
        self.DelDpInterfaces = channel.unary_unary(
                '/faucetconfserver.FaucetConfServer/DelDpInterfaces',
                request_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.DelDpInterfacesRequest.SerializeToString,
                response_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.DelDpInterfacesReply.FromString,
                )
        self.DelDps = channel.unary_unary(
                '/faucetconfserver.FaucetConfServer/DelDps',
                request_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.DelDpsRequest.SerializeToString,
                response_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.DelDpsReply.FromString,
                )
        self.SetRemoteMirrorPort = channel.unary_unary(
                '/faucetconfserver.FaucetConfServer/SetRemoteMirrorPort',
                request_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.SetRemoteMirrorPortRequest.SerializeToString,
                response_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.SetRemoteMirrorPortReply.FromString,
                )
        self.GetDpNames = channel.unary_unary(
                '/faucetconfserver.FaucetConfServer/GetDpNames',
                request_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.GetDpNamesRequest.SerializeToString,
                response_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.GetDpNamesReply.FromString,
                )
        self.GetDpIDs = channel.unary_unary(
                '/faucetconfserver.FaucetConfServer/GetDpIDs',
                request_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.GetDpIDsRequest.SerializeToString,
                response_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.GetDpIDsReply.FromString,
                )
        self.GetAclNames = channel.unary_unary(
                '/faucetconfserver.FaucetConfServer/GetAclNames',
                request_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.GetAclNamesRequest.SerializeToString,
                response_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.GetAclNamesReply.FromString,
                )
        self.SetDps = channel.unary_unary(
                '/faucetconfserver.FaucetConfServer/SetDps',
                request_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.SetDpsRequest.SerializeToString,
                response_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.SetDpsReply.FromString,
                )
        self.MakeCoprocessorPort = channel.unary_unary(
                '/faucetconfserver.FaucetConfServer/MakeCoprocessorPort',
                request_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.MakeCoprocessorPortRequest.SerializeToString,
                response_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.MakeCoprocessorPortReply.FromString,
                )
        self.SetVlanOutAcl = channel.unary_unary(
                '/faucetconfserver.FaucetConfServer/SetVlanOutAcl',
                request_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.SetVlanOutAclRequest.SerializeToString,
                response_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.SetVlanOutAclReply.FromString,
                )


class FaucetConfServerServicer(object):
    """NOTE: currently some of these API calls allow specifying an optional config_file.
    This will be removed in future so the client does not need/have knowledge of the underlying YAML store.
    """

    def GetConfigFile(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetConfigFile(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DelConfigFromFile(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddPortMirror(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemovePortMirror(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClearPortMirror(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddPortAcl(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemovePortAcl(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetPortAcl(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDpInterfaces(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDpInfo(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DelDpInterfaces(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DelDps(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetRemoteMirrorPort(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDpNames(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDpIDs(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAclNames(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDps(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MakeCoprocessorPort(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetVlanOutAcl(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FaucetConfServerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetConfigFile': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConfigFile,
                    request_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.GetConfigFileRequest.FromString,
                    response_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.GetConfigFileReply.SerializeToString,
            ),
            'SetConfigFile': grpc.unary_unary_rpc_method_handler(
                    servicer.SetConfigFile,
                    request_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.SetConfigFileRequest.FromString,
                    response_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.SetConfigFileReply.SerializeToString,
            ),
            'DelConfigFromFile': grpc.unary_unary_rpc_method_handler(
                    servicer.DelConfigFromFile,
                    request_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.DelConfigFromFileRequest.FromString,
                    response_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.DelConfigFromFileReply.SerializeToString,
            ),
            'AddPortMirror': grpc.unary_unary_rpc_method_handler(
                    servicer.AddPortMirror,
                    request_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.AddPortMirrorRequest.FromString,
                    response_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.AddPortMirrorReply.SerializeToString,
            ),
            'RemovePortMirror': grpc.unary_unary_rpc_method_handler(
                    servicer.RemovePortMirror,
                    request_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.RemovePortMirrorRequest.FromString,
                    response_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.RemovePortMirrorReply.SerializeToString,
            ),
            'ClearPortMirror': grpc.unary_unary_rpc_method_handler(
                    servicer.ClearPortMirror,
                    request_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.ClearPortMirrorRequest.FromString,
                    response_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.ClearPortMirrorReply.SerializeToString,
            ),
            'AddPortAcl': grpc.unary_unary_rpc_method_handler(
                    servicer.AddPortAcl,
                    request_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.AddPortAclRequest.FromString,
                    response_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.AddPortAclReply.SerializeToString,
            ),
            'RemovePortAcl': grpc.unary_unary_rpc_method_handler(
                    servicer.RemovePortAcl,
                    request_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.RemovePortAclRequest.FromString,
                    response_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.RemovePortAclReply.SerializeToString,
            ),
            'SetPortAcl': grpc.unary_unary_rpc_method_handler(
                    servicer.SetPortAcl,
                    request_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.SetPortAclRequest.FromString,
                    response_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.SetPortAclReply.SerializeToString,
            ),
            'SetDpInterfaces': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDpInterfaces,
                    request_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.SetDpInterfacesRequest.FromString,
                    response_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.SetDpInterfacesReply.SerializeToString,
            ),
            'GetDpInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDpInfo,
                    request_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.GetDpInfoRequest.FromString,
                    response_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.GetDpInfoReply.SerializeToString,
            ),
            'DelDpInterfaces': grpc.unary_unary_rpc_method_handler(
                    servicer.DelDpInterfaces,
                    request_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.DelDpInterfacesRequest.FromString,
                    response_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.DelDpInterfacesReply.SerializeToString,
            ),
            'DelDps': grpc.unary_unary_rpc_method_handler(
                    servicer.DelDps,
                    request_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.DelDpsRequest.FromString,
                    response_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.DelDpsReply.SerializeToString,
            ),
            'SetRemoteMirrorPort': grpc.unary_unary_rpc_method_handler(
                    servicer.SetRemoteMirrorPort,
                    request_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.SetRemoteMirrorPortRequest.FromString,
                    response_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.SetRemoteMirrorPortReply.SerializeToString,
            ),
            'GetDpNames': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDpNames,
                    request_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.GetDpNamesRequest.FromString,
                    response_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.GetDpNamesReply.SerializeToString,
            ),
            'GetDpIDs': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDpIDs,
                    request_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.GetDpIDsRequest.FromString,
                    response_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.GetDpIDsReply.SerializeToString,
            ),
            'GetAclNames': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAclNames,
                    request_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.GetAclNamesRequest.FromString,
                    response_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.GetAclNamesReply.SerializeToString,
            ),
            'SetDps': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDps,
                    request_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.SetDpsRequest.FromString,
                    response_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.SetDpsReply.SerializeToString,
            ),
            'MakeCoprocessorPort': grpc.unary_unary_rpc_method_handler(
                    servicer.MakeCoprocessorPort,
                    request_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.MakeCoprocessorPortRequest.FromString,
                    response_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.MakeCoprocessorPortReply.SerializeToString,
            ),
            'SetVlanOutAcl': grpc.unary_unary_rpc_method_handler(
                    servicer.SetVlanOutAcl,
                    request_deserializer=faucetconfrpc_dot_faucetconfrpc__pb2.SetVlanOutAclRequest.FromString,
                    response_serializer=faucetconfrpc_dot_faucetconfrpc__pb2.SetVlanOutAclReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'faucetconfserver.FaucetConfServer', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FaucetConfServer(object):
    """NOTE: currently some of these API calls allow specifying an optional config_file.
    This will be removed in future so the client does not need/have knowledge of the underlying YAML store.
    """

    @staticmethod
    def GetConfigFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/faucetconfserver.FaucetConfServer/GetConfigFile',
            faucetconfrpc_dot_faucetconfrpc__pb2.GetConfigFileRequest.SerializeToString,
            faucetconfrpc_dot_faucetconfrpc__pb2.GetConfigFileReply.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetConfigFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/faucetconfserver.FaucetConfServer/SetConfigFile',
            faucetconfrpc_dot_faucetconfrpc__pb2.SetConfigFileRequest.SerializeToString,
            faucetconfrpc_dot_faucetconfrpc__pb2.SetConfigFileReply.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DelConfigFromFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/faucetconfserver.FaucetConfServer/DelConfigFromFile',
            faucetconfrpc_dot_faucetconfrpc__pb2.DelConfigFromFileRequest.SerializeToString,
            faucetconfrpc_dot_faucetconfrpc__pb2.DelConfigFromFileReply.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddPortMirror(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/faucetconfserver.FaucetConfServer/AddPortMirror',
            faucetconfrpc_dot_faucetconfrpc__pb2.AddPortMirrorRequest.SerializeToString,
            faucetconfrpc_dot_faucetconfrpc__pb2.AddPortMirrorReply.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemovePortMirror(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/faucetconfserver.FaucetConfServer/RemovePortMirror',
            faucetconfrpc_dot_faucetconfrpc__pb2.RemovePortMirrorRequest.SerializeToString,
            faucetconfrpc_dot_faucetconfrpc__pb2.RemovePortMirrorReply.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ClearPortMirror(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/faucetconfserver.FaucetConfServer/ClearPortMirror',
            faucetconfrpc_dot_faucetconfrpc__pb2.ClearPortMirrorRequest.SerializeToString,
            faucetconfrpc_dot_faucetconfrpc__pb2.ClearPortMirrorReply.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddPortAcl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/faucetconfserver.FaucetConfServer/AddPortAcl',
            faucetconfrpc_dot_faucetconfrpc__pb2.AddPortAclRequest.SerializeToString,
            faucetconfrpc_dot_faucetconfrpc__pb2.AddPortAclReply.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemovePortAcl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/faucetconfserver.FaucetConfServer/RemovePortAcl',
            faucetconfrpc_dot_faucetconfrpc__pb2.RemovePortAclRequest.SerializeToString,
            faucetconfrpc_dot_faucetconfrpc__pb2.RemovePortAclReply.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetPortAcl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/faucetconfserver.FaucetConfServer/SetPortAcl',
            faucetconfrpc_dot_faucetconfrpc__pb2.SetPortAclRequest.SerializeToString,
            faucetconfrpc_dot_faucetconfrpc__pb2.SetPortAclReply.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDpInterfaces(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/faucetconfserver.FaucetConfServer/SetDpInterfaces',
            faucetconfrpc_dot_faucetconfrpc__pb2.SetDpInterfacesRequest.SerializeToString,
            faucetconfrpc_dot_faucetconfrpc__pb2.SetDpInterfacesReply.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDpInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/faucetconfserver.FaucetConfServer/GetDpInfo',
            faucetconfrpc_dot_faucetconfrpc__pb2.GetDpInfoRequest.SerializeToString,
            faucetconfrpc_dot_faucetconfrpc__pb2.GetDpInfoReply.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DelDpInterfaces(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/faucetconfserver.FaucetConfServer/DelDpInterfaces',
            faucetconfrpc_dot_faucetconfrpc__pb2.DelDpInterfacesRequest.SerializeToString,
            faucetconfrpc_dot_faucetconfrpc__pb2.DelDpInterfacesReply.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DelDps(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/faucetconfserver.FaucetConfServer/DelDps',
            faucetconfrpc_dot_faucetconfrpc__pb2.DelDpsRequest.SerializeToString,
            faucetconfrpc_dot_faucetconfrpc__pb2.DelDpsReply.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetRemoteMirrorPort(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/faucetconfserver.FaucetConfServer/SetRemoteMirrorPort',
            faucetconfrpc_dot_faucetconfrpc__pb2.SetRemoteMirrorPortRequest.SerializeToString,
            faucetconfrpc_dot_faucetconfrpc__pb2.SetRemoteMirrorPortReply.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDpNames(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/faucetconfserver.FaucetConfServer/GetDpNames',
            faucetconfrpc_dot_faucetconfrpc__pb2.GetDpNamesRequest.SerializeToString,
            faucetconfrpc_dot_faucetconfrpc__pb2.GetDpNamesReply.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDpIDs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/faucetconfserver.FaucetConfServer/GetDpIDs',
            faucetconfrpc_dot_faucetconfrpc__pb2.GetDpIDsRequest.SerializeToString,
            faucetconfrpc_dot_faucetconfrpc__pb2.GetDpIDsReply.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAclNames(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/faucetconfserver.FaucetConfServer/GetAclNames',
            faucetconfrpc_dot_faucetconfrpc__pb2.GetAclNamesRequest.SerializeToString,
            faucetconfrpc_dot_faucetconfrpc__pb2.GetAclNamesReply.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDps(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/faucetconfserver.FaucetConfServer/SetDps',
            faucetconfrpc_dot_faucetconfrpc__pb2.SetDpsRequest.SerializeToString,
            faucetconfrpc_dot_faucetconfrpc__pb2.SetDpsReply.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MakeCoprocessorPort(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/faucetconfserver.FaucetConfServer/MakeCoprocessorPort',
            faucetconfrpc_dot_faucetconfrpc__pb2.MakeCoprocessorPortRequest.SerializeToString,
            faucetconfrpc_dot_faucetconfrpc__pb2.MakeCoprocessorPortReply.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetVlanOutAcl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/faucetconfserver.FaucetConfServer/SetVlanOutAcl',
            faucetconfrpc_dot_faucetconfrpc__pb2.SetVlanOutAclRequest.SerializeToString,
            faucetconfrpc_dot_faucetconfrpc__pb2.SetVlanOutAclReply.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: faucetconfrpc/faucetconfrpc.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='faucetconfrpc/faucetconfrpc.proto',
  package='faucetconfserver',
  syntax='proto3',
  serialized_options=b'Z\022.;faucetconfserver',
  serialized_pb=b'\n!faucetconfrpc/faucetconfrpc.proto\x12\x10\x66\x61ucetconfserver\"/\n\x14GetConfigFileRequest\x12\x17\n\x0f\x63onfig_filename\x18\x01 \x01(\t\")\n\x12GetConfigFileReply\x12\x13\n\x0b\x63onfig_yaml\x18\x01 \x01(\t\"q\n\x14SetConfigFileRequest\x12\x17\n\x0f\x63onfig_filename\x18\x01 \x01(\t\x12\x13\n\x0b\x63onfig_yaml\x18\x02 \x01(\t\x12\r\n\x05merge\x18\x03 \x01(\x08\x12\x1c\n\x14\x64\x65l_config_yaml_keys\x18\x04 \x01(\t\"\x14\n\x12SetConfigFileReply\"M\n\x18\x44\x65lConfigFromFileRequest\x12\x17\n\x0f\x63onfig_filename\x18\x01 \x01(\t\x12\x18\n\x10\x63onfig_yaml_keys\x18\x02 \x01(\t\"\x18\n\x16\x44\x65lConfigFromFileReply\"\x82\x01\n\x1aSetRemoteMirrorPortRequest\x12\x0f\n\x07\x64p_name\x18\x01 \x01(\t\x12\x0f\n\x07port_no\x18\x02 \x01(\r\x12\x12\n\ntunnel_vid\x18\x03 \x01(\r\x12\x16\n\x0eremote_dp_name\x18\x04 \x01(\t\x12\x16\n\x0eremote_port_no\x18\x05 \x01(\r\"\x1a\n\x18SetRemoteMirrorPortReply\"P\n\x14\x41\x64\x64PortMirrorRequest\x12\x0f\n\x07\x64p_name\x18\x01 \x01(\t\x12\x0f\n\x07port_no\x18\x02 \x01(\r\x12\x16\n\x0emirror_port_no\x18\x03 \x01(\r\"\x14\n\x12\x41\x64\x64PortMirrorReply\"e\n\x1aMakeCoprocessorPortRequest\x12\x0f\n\x07\x64p_name\x18\x01 \x01(\t\x12\x0f\n\x07port_no\x18\x02 \x01(\r\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08strategy\x18\x04 \x01(\t\"\x1a\n\x18MakeCoprocessorPortReply\"S\n\x17RemovePortMirrorRequest\x12\x0f\n\x07\x64p_name\x18\x01 \x01(\t\x12\x0f\n\x07port_no\x18\x02 \x01(\r\x12\x16\n\x0emirror_port_no\x18\x03 \x01(\r\"\x17\n\x15RemovePortMirrorReply\"A\n\x16\x43learPortMirrorRequest\x12\x0f\n\x07\x64p_name\x18\x01 \x01(\t\x12\x16\n\x0emirror_port_no\x18\x02 \x01(\r\"\x16\n\x14\x43learPortMirrorReply\":\n\x14SetVlanOutAclRequest\x12\x11\n\tvlan_name\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x63l_out\x18\x02 \x01(\t\"\x14\n\x12SetVlanOutAclReply\"C\n\x11SetPortAclRequest\x12\x0f\n\x07\x64p_name\x18\x01 \x01(\t\x12\x0f\n\x07port_no\x18\x02 \x01(\r\x12\x0c\n\x04\x61\x63ls\x18\x03 \x01(\t\"\x11\n\x0fSetPortAclReply\"B\n\x11\x41\x64\x64PortAclRequest\x12\x0f\n\x07\x64p_name\x18\x01 \x01(\t\x12\x0f\n\x07port_no\x18\x02 \x01(\r\x12\x0b\n\x03\x61\x63l\x18\x03 \x01(\t\"\x11\n\x0f\x41\x64\x64PortAclReply\"E\n\x14RemovePortAclRequest\x12\x0f\n\x07\x64p_name\x18\x01 \x01(\t\x12\x0f\n\x07port_no\x18\x02 \x01(\r\x12\x0b\n\x03\x61\x63l\x18\x03 \x01(\t\"\x14\n\x12RemovePortAclReply\"4\n\x0cSetInterface\x12\x0f\n\x07port_no\x18\x01 \x01(\r\x12\x13\n\x0b\x63onfig_yaml\x18\x02 \x01(\t\"\\\n\x0fSetDpInterfaces\x12\x0f\n\x07\x64p_name\x18\x01 \x01(\t\x12\x38\n\x10interface_config\x18\x02 \x03(\x0b\x32\x1e.faucetconfserver.SetInterface\"V\n\x16SetDpInterfacesRequest\x12<\n\x11interfaces_config\x18\x01 \x03(\x0b\x32!.faucetconfserver.SetDpInterfaces\"\x16\n\x14SetDpInterfacesReply\"<\n\x10GetDpInfoRequest\x12\x0f\n\x07\x64p_name\x18\x01 \x01(\t\x12\x17\n\x0f\x63onfig_filename\x18\x02 \x01(\t\"C\n\rInterfaceInfo\x12\x0f\n\x07port_no\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"o\n\x06\x44pInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x64p_id\x18\x02 \x01(\x04\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x33\n\ninterfaces\x18\x04 \x03(\x0b\x32\x1f.faucetconfserver.InterfaceInfo\"7\n\x0eGetDpInfoReply\x12%\n\x03\x64ps\x18\x01 \x03(\x0b\x32\x18.faucetconfserver.DpInfo\"f\n\x16\x44\x65lDpInterfacesRequest\x12\x33\n\x11interfaces_config\x18\x01 \x03(\x0b\x32\x18.faucetconfserver.DpInfo\x12\x17\n\x0f\x64\x65lete_empty_dp\x18\x02 \x01(\x08\"\x16\n\x14\x44\x65lDpInterfacesReply\"D\n\rDelDpsRequest\x12\x33\n\x11interfaces_config\x18\x01 \x03(\x0b\x32\x18.faucetconfserver.DpInfo\"\r\n\x0b\x44\x65lDpsReply\"\x13\n\x11GetDpNamesRequest\"\"\n\x0fGetDpNamesReply\x12\x0f\n\x07\x64p_name\x18\x01 \x03(\t\"\x11\n\x0fGetDpIDsRequest\"\x1e\n\rGetDpIDsReply\x12\r\n\x05\x64p_id\x18\x01 \x03(\x04\"&\n\x12GetAclNamesRequest\x12\x10\n\x08\x61\x63l_name\x18\x01 \x03(\t\"$\n\x10GetAclNamesReply\x12\x10\n\x08\x61\x63l_name\x18\x01 \x03(\t\"-\n\x05SetDp\x12\x0f\n\x07\x64p_name\x18\x01 \x01(\t\x12\x13\n\x0b\x63onfig_yaml\x18\x02 \x01(\t\";\n\rSetDpsRequest\x12*\n\tdp_config\x18\x01 \x03(\x0b\x32\x17.faucetconfserver.SetDp\"\r\n\x0bSetDpsReply2\x8b\x0f\n\x10\x46\x61ucetConfServer\x12_\n\rGetConfigFile\x12&.faucetconfserver.GetConfigFileRequest\x1a$.faucetconfserver.GetConfigFileReply\"\x00\x12_\n\rSetConfigFile\x12&.faucetconfserver.SetConfigFileRequest\x1a$.faucetconfserver.SetConfigFileReply\"\x00\x12k\n\x11\x44\x65lConfigFromFile\x12*.faucetconfserver.DelConfigFromFileRequest\x1a(.faucetconfserver.DelConfigFromFileReply\"\x00\x12_\n\rAddPortMirror\x12&.faucetconfserver.AddPortMirrorRequest\x1a$.faucetconfserver.AddPortMirrorReply\"\x00\x12h\n\x10RemovePortMirror\x12).faucetconfserver.RemovePortMirrorRequest\x1a\'.faucetconfserver.RemovePortMirrorReply\"\x00\x12\x65\n\x0f\x43learPortMirror\x12(.faucetconfserver.ClearPortMirrorRequest\x1a&.faucetconfserver.ClearPortMirrorReply\"\x00\x12V\n\nAddPortAcl\x12#.faucetconfserver.AddPortAclRequest\x1a!.faucetconfserver.AddPortAclReply\"\x00\x12_\n\rRemovePortAcl\x12&.faucetconfserver.RemovePortAclRequest\x1a$.faucetconfserver.RemovePortAclReply\"\x00\x12V\n\nSetPortAcl\x12#.faucetconfserver.SetPortAclRequest\x1a!.faucetconfserver.SetPortAclReply\"\x00\x12\x65\n\x0fSetDpInterfaces\x12(.faucetconfserver.SetDpInterfacesRequest\x1a&.faucetconfserver.SetDpInterfacesReply\"\x00\x12S\n\tGetDpInfo\x12\".faucetconfserver.GetDpInfoRequest\x1a .faucetconfserver.GetDpInfoReply\"\x00\x12\x65\n\x0f\x44\x65lDpInterfaces\x12(.faucetconfserver.DelDpInterfacesRequest\x1a&.faucetconfserver.DelDpInterfacesReply\"\x00\x12J\n\x06\x44\x65lDps\x12\x1f.faucetconfserver.DelDpsRequest\x1a\x1d.faucetconfserver.DelDpsReply\"\x00\x12q\n\x13SetRemoteMirrorPort\x12,.faucetconfserver.SetRemoteMirrorPortRequest\x1a*.faucetconfserver.SetRemoteMirrorPortReply\"\x00\x12V\n\nGetDpNames\x12#.faucetconfserver.GetDpNamesRequest\x1a!.faucetconfserver.GetDpNamesReply\"\x00\x12P\n\x08GetDpIDs\x12!.faucetconfserver.GetDpIDsRequest\x1a\x1f.faucetconfserver.GetDpIDsReply\"\x00\x12Y\n\x0bGetAclNames\x12$.faucetconfserver.GetAclNamesRequest\x1a\".faucetconfserver.GetAclNamesReply\"\x00\x12J\n\x06SetDps\x12\x1f.faucetconfserver.SetDpsRequest\x1a\x1d.faucetconfserver.SetDpsReply\"\x00\x12q\n\x13MakeCoprocessorPort\x12,.faucetconfserver.MakeCoprocessorPortRequest\x1a*.faucetconfserver.MakeCoprocessorPortReply\"\x00\x12_\n\rSetVlanOutAcl\x12&.faucetconfserver.SetVlanOutAclRequest\x1a$.faucetconfserver.SetVlanOutAclReply\"\x00\x42\x14Z\x12.;faucetconfserverb\x06proto3'
)




_GETCONFIGFILEREQUEST = _descriptor.Descriptor(
  name='GetConfigFileRequest',
  full_name='faucetconfserver.GetConfigFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config_filename', full_name='faucetconfserver.GetConfigFileRequest.config_filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55,
  serialized_end=102,
)


_GETCONFIGFILEREPLY = _descriptor.Descriptor(
  name='GetConfigFileReply',
  full_name='faucetconfserver.GetConfigFileReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config_yaml', full_name='faucetconfserver.GetConfigFileReply.config_yaml', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=104,
  serialized_end=145,
)


_SETCONFIGFILEREQUEST = _descriptor.Descriptor(
  name='SetConfigFileRequest',
  full_name='faucetconfserver.SetConfigFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config_filename', full_name='faucetconfserver.SetConfigFileRequest.config_filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config_yaml', full_name='faucetconfserver.SetConfigFileRequest.config_yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='merge', full_name='faucetconfserver.SetConfigFileRequest.merge', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='del_config_yaml_keys', full_name='faucetconfserver.SetConfigFileRequest.del_config_yaml_keys', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=147,
  serialized_end=260,
)


_SETCONFIGFILEREPLY = _descriptor.Descriptor(
  name='SetConfigFileReply',
  full_name='faucetconfserver.SetConfigFileReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=262,
  serialized_end=282,
)


_DELCONFIGFROMFILEREQUEST = _descriptor.Descriptor(
  name='DelConfigFromFileRequest',
  full_name='faucetconfserver.DelConfigFromFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config_filename', full_name='faucetconfserver.DelConfigFromFileRequest.config_filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config_yaml_keys', full_name='faucetconfserver.DelConfigFromFileRequest.config_yaml_keys', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=284,
  serialized_end=361,
)


_DELCONFIGFROMFILEREPLY = _descriptor.Descriptor(
  name='DelConfigFromFileReply',
  full_name='faucetconfserver.DelConfigFromFileReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=363,
  serialized_end=387,
)


_SETREMOTEMIRRORPORTREQUEST = _descriptor.Descriptor(
  name='SetRemoteMirrorPortRequest',
  full_name='faucetconfserver.SetRemoteMirrorPortRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dp_name', full_name='faucetconfserver.SetRemoteMirrorPortRequest.dp_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_no', full_name='faucetconfserver.SetRemoteMirrorPortRequest.port_no', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tunnel_vid', full_name='faucetconfserver.SetRemoteMirrorPortRequest.tunnel_vid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remote_dp_name', full_name='faucetconfserver.SetRemoteMirrorPortRequest.remote_dp_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remote_port_no', full_name='faucetconfserver.SetRemoteMirrorPortRequest.remote_port_no', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=390,
  serialized_end=520,
)


_SETREMOTEMIRRORPORTREPLY = _descriptor.Descriptor(
  name='SetRemoteMirrorPortReply',
  full_name='faucetconfserver.SetRemoteMirrorPortReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=522,
  serialized_end=548,
)


_ADDPORTMIRRORREQUEST = _descriptor.Descriptor(
  name='AddPortMirrorRequest',
  full_name='faucetconfserver.AddPortMirrorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dp_name', full_name='faucetconfserver.AddPortMirrorRequest.dp_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_no', full_name='faucetconfserver.AddPortMirrorRequest.port_no', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mirror_port_no', full_name='faucetconfserver.AddPortMirrorRequest.mirror_port_no', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=550,
  serialized_end=630,
)


_ADDPORTMIRRORREPLY = _descriptor.Descriptor(
  name='AddPortMirrorReply',
  full_name='faucetconfserver.AddPortMirrorReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=632,
  serialized_end=652,
)


_MAKECOPROCESSORPORTREQUEST = _descriptor.Descriptor(
  name='MakeCoprocessorPortRequest',
  full_name='faucetconfserver.MakeCoprocessorPortRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dp_name', full_name='faucetconfserver.MakeCoprocessorPortRequest.dp_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_no', full_name='faucetconfserver.MakeCoprocessorPortRequest.port_no', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='faucetconfserver.MakeCoprocessorPortRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='strategy', full_name='faucetconfserver.MakeCoprocessorPortRequest.strategy', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=654,
  serialized_end=755,
)


_MAKECOPROCESSORPORTREPLY = _descriptor.Descriptor(
  name='MakeCoprocessorPortReply',
  full_name='faucetconfserver.MakeCoprocessorPortReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=757,
  serialized_end=783,
)


_REMOVEPORTMIRRORREQUEST = _descriptor.Descriptor(
  name='RemovePortMirrorRequest',
  full_name='faucetconfserver.RemovePortMirrorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dp_name', full_name='faucetconfserver.RemovePortMirrorRequest.dp_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_no', full_name='faucetconfserver.RemovePortMirrorRequest.port_no', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mirror_port_no', full_name='faucetconfserver.RemovePortMirrorRequest.mirror_port_no', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=785,
  serialized_end=868,
)


_REMOVEPORTMIRRORREPLY = _descriptor.Descriptor(
  name='RemovePortMirrorReply',
  full_name='faucetconfserver.RemovePortMirrorReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=870,
  serialized_end=893,
)


_CLEARPORTMIRRORREQUEST = _descriptor.Descriptor(
  name='ClearPortMirrorRequest',
  full_name='faucetconfserver.ClearPortMirrorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dp_name', full_name='faucetconfserver.ClearPortMirrorRequest.dp_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mirror_port_no', full_name='faucetconfserver.ClearPortMirrorRequest.mirror_port_no', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=895,
  serialized_end=960,
)


_CLEARPORTMIRRORREPLY = _descriptor.Descriptor(
  name='ClearPortMirrorReply',
  full_name='faucetconfserver.ClearPortMirrorReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=962,
  serialized_end=984,
)


_SETVLANOUTACLREQUEST = _descriptor.Descriptor(
  name='SetVlanOutAclRequest',
  full_name='faucetconfserver.SetVlanOutAclRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vlan_name', full_name='faucetconfserver.SetVlanOutAclRequest.vlan_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acl_out', full_name='faucetconfserver.SetVlanOutAclRequest.acl_out', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=986,
  serialized_end=1044,
)


_SETVLANOUTACLREPLY = _descriptor.Descriptor(
  name='SetVlanOutAclReply',
  full_name='faucetconfserver.SetVlanOutAclReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1046,
  serialized_end=1066,
)


_SETPORTACLREQUEST = _descriptor.Descriptor(
  name='SetPortAclRequest',
  full_name='faucetconfserver.SetPortAclRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dp_name', full_name='faucetconfserver.SetPortAclRequest.dp_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_no', full_name='faucetconfserver.SetPortAclRequest.port_no', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acls', full_name='faucetconfserver.SetPortAclRequest.acls', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1068,
  serialized_end=1135,
)


_SETPORTACLREPLY = _descriptor.Descriptor(
  name='SetPortAclReply',
  full_name='faucetconfserver.SetPortAclReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1137,
  serialized_end=1154,
)


_ADDPORTACLREQUEST = _descriptor.Descriptor(
  name='AddPortAclRequest',
  full_name='faucetconfserver.AddPortAclRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dp_name', full_name='faucetconfserver.AddPortAclRequest.dp_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_no', full_name='faucetconfserver.AddPortAclRequest.port_no', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acl', full_name='faucetconfserver.AddPortAclRequest.acl', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1156,
  serialized_end=1222,
)


_ADDPORTACLREPLY = _descriptor.Descriptor(
  name='AddPortAclReply',
  full_name='faucetconfserver.AddPortAclReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1224,
  serialized_end=1241,
)


_REMOVEPORTACLREQUEST = _descriptor.Descriptor(
  name='RemovePortAclRequest',
  full_name='faucetconfserver.RemovePortAclRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dp_name', full_name='faucetconfserver.RemovePortAclRequest.dp_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_no', full_name='faucetconfserver.RemovePortAclRequest.port_no', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acl', full_name='faucetconfserver.RemovePortAclRequest.acl', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1243,
  serialized_end=1312,
)


_REMOVEPORTACLREPLY = _descriptor.Descriptor(
  name='RemovePortAclReply',
  full_name='faucetconfserver.RemovePortAclReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1314,
  serialized_end=1334,
)


_SETINTERFACE = _descriptor.Descriptor(
  name='SetInterface',
  full_name='faucetconfserver.SetInterface',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port_no', full_name='faucetconfserver.SetInterface.port_no', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config_yaml', full_name='faucetconfserver.SetInterface.config_yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1336,
  serialized_end=1388,
)


_SETDPINTERFACES = _descriptor.Descriptor(
  name='SetDpInterfaces',
  full_name='faucetconfserver.SetDpInterfaces',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dp_name', full_name='faucetconfserver.SetDpInterfaces.dp_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interface_config', full_name='faucetconfserver.SetDpInterfaces.interface_config', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1390,
  serialized_end=1482,
)


_SETDPINTERFACESREQUEST = _descriptor.Descriptor(
  name='SetDpInterfacesRequest',
  full_name='faucetconfserver.SetDpInterfacesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interfaces_config', full_name='faucetconfserver.SetDpInterfacesRequest.interfaces_config', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1484,
  serialized_end=1570,
)


_SETDPINTERFACESREPLY = _descriptor.Descriptor(
  name='SetDpInterfacesReply',
  full_name='faucetconfserver.SetDpInterfacesReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1572,
  serialized_end=1594,
)


_GETDPINFOREQUEST = _descriptor.Descriptor(
  name='GetDpInfoRequest',
  full_name='faucetconfserver.GetDpInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dp_name', full_name='faucetconfserver.GetDpInfoRequest.dp_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config_filename', full_name='faucetconfserver.GetDpInfoRequest.config_filename', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1596,
  serialized_end=1656,
)


_INTERFACEINFO = _descriptor.Descriptor(
  name='InterfaceInfo',
  full_name='faucetconfserver.InterfaceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port_no', full_name='faucetconfserver.InterfaceInfo.port_no', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='faucetconfserver.InterfaceInfo.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='faucetconfserver.InterfaceInfo.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1658,
  serialized_end=1725,
)


_DPINFO = _descriptor.Descriptor(
  name='DpInfo',
  full_name='faucetconfserver.DpInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='faucetconfserver.DpInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dp_id', full_name='faucetconfserver.DpInfo.dp_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='faucetconfserver.DpInfo.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interfaces', full_name='faucetconfserver.DpInfo.interfaces', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1727,
  serialized_end=1838,
)


_GETDPINFOREPLY = _descriptor.Descriptor(
  name='GetDpInfoReply',
  full_name='faucetconfserver.GetDpInfoReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dps', full_name='faucetconfserver.GetDpInfoReply.dps', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1840,
  serialized_end=1895,
)


_DELDPINTERFACESREQUEST = _descriptor.Descriptor(
  name='DelDpInterfacesRequest',
  full_name='faucetconfserver.DelDpInterfacesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interfaces_config', full_name='faucetconfserver.DelDpInterfacesRequest.interfaces_config', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delete_empty_dp', full_name='faucetconfserver.DelDpInterfacesRequest.delete_empty_dp', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1897,
  serialized_end=1999,
)


_DELDPINTERFACESREPLY = _descriptor.Descriptor(
  name='DelDpInterfacesReply',
  full_name='faucetconfserver.DelDpInterfacesReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2001,
  serialized_end=2023,
)


_DELDPSREQUEST = _descriptor.Descriptor(
  name='DelDpsRequest',
  full_name='faucetconfserver.DelDpsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interfaces_config', full_name='faucetconfserver.DelDpsRequest.interfaces_config', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2025,
  serialized_end=2093,
)


_DELDPSREPLY = _descriptor.Descriptor(
  name='DelDpsReply',
  full_name='faucetconfserver.DelDpsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2095,
  serialized_end=2108,
)


_GETDPNAMESREQUEST = _descriptor.Descriptor(
  name='GetDpNamesRequest',
  full_name='faucetconfserver.GetDpNamesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2110,
  serialized_end=2129,
)


_GETDPNAMESREPLY = _descriptor.Descriptor(
  name='GetDpNamesReply',
  full_name='faucetconfserver.GetDpNamesReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dp_name', full_name='faucetconfserver.GetDpNamesReply.dp_name', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2131,
  serialized_end=2165,
)


_GETDPIDSREQUEST = _descriptor.Descriptor(
  name='GetDpIDsRequest',
  full_name='faucetconfserver.GetDpIDsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2167,
  serialized_end=2184,
)


_GETDPIDSREPLY = _descriptor.Descriptor(
  name='GetDpIDsReply',
  full_name='faucetconfserver.GetDpIDsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dp_id', full_name='faucetconfserver.GetDpIDsReply.dp_id', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2186,
  serialized_end=2216,
)


_GETACLNAMESREQUEST = _descriptor.Descriptor(
  name='GetAclNamesRequest',
  full_name='faucetconfserver.GetAclNamesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='acl_name', full_name='faucetconfserver.GetAclNamesRequest.acl_name', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2218,
  serialized_end=2256,
)


_GETACLNAMESREPLY = _descriptor.Descriptor(
  name='GetAclNamesReply',
  full_name='faucetconfserver.GetAclNamesReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='acl_name', full_name='faucetconfserver.GetAclNamesReply.acl_name', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2258,
  serialized_end=2294,
)


_SETDP = _descriptor.Descriptor(
  name='SetDp',
  full_name='faucetconfserver.SetDp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dp_name', full_name='faucetconfserver.SetDp.dp_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config_yaml', full_name='faucetconfserver.SetDp.config_yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2296,
  serialized_end=2341,
)


_SETDPSREQUEST = _descriptor.Descriptor(
  name='SetDpsRequest',
  full_name='faucetconfserver.SetDpsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dp_config', full_name='faucetconfserver.SetDpsRequest.dp_config', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2343,
  serialized_end=2402,
)


_SETDPSREPLY = _descriptor.Descriptor(
  name='SetDpsReply',
  full_name='faucetconfserver.SetDpsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2404,
  serialized_end=2417,
)

_SETDPINTERFACES.fields_by_name['interface_config'].message_type = _SETINTERFACE
_SETDPINTERFACESREQUEST.fields_by_name['interfaces_config'].message_type = _SETDPINTERFACES
_DPINFO.fields_by_name['interfaces'].message_type = _INTERFACEINFO
_GETDPINFOREPLY.fields_by_name['dps'].message_type = _DPINFO
_DELDPINTERFACESREQUEST.fields_by_name['interfaces_config'].message_type = _DPINFO
_DELDPSREQUEST.fields_by_name['interfaces_config'].message_type = _DPINFO
_SETDPSREQUEST.fields_by_name['dp_config'].message_type = _SETDP
DESCRIPTOR.message_types_by_name['GetConfigFileRequest'] = _GETCONFIGFILEREQUEST
DESCRIPTOR.message_types_by_name['GetConfigFileReply'] = _GETCONFIGFILEREPLY
DESCRIPTOR.message_types_by_name['SetConfigFileRequest'] = _SETCONFIGFILEREQUEST
DESCRIPTOR.message_types_by_name['SetConfigFileReply'] = _SETCONFIGFILEREPLY
DESCRIPTOR.message_types_by_name['DelConfigFromFileRequest'] = _DELCONFIGFROMFILEREQUEST
DESCRIPTOR.message_types_by_name['DelConfigFromFileReply'] = _DELCONFIGFROMFILEREPLY
DESCRIPTOR.message_types_by_name['SetRemoteMirrorPortRequest'] = _SETREMOTEMIRRORPORTREQUEST
DESCRIPTOR.message_types_by_name['SetRemoteMirrorPortReply'] = _SETREMOTEMIRRORPORTREPLY
DESCRIPTOR.message_types_by_name['AddPortMirrorRequest'] = _ADDPORTMIRRORREQUEST
DESCRIPTOR.message_types_by_name['AddPortMirrorReply'] = _ADDPORTMIRRORREPLY
DESCRIPTOR.message_types_by_name['MakeCoprocessorPortRequest'] = _MAKECOPROCESSORPORTREQUEST
DESCRIPTOR.message_types_by_name['MakeCoprocessorPortReply'] = _MAKECOPROCESSORPORTREPLY
DESCRIPTOR.message_types_by_name['RemovePortMirrorRequest'] = _REMOVEPORTMIRRORREQUEST
DESCRIPTOR.message_types_by_name['RemovePortMirrorReply'] = _REMOVEPORTMIRRORREPLY
DESCRIPTOR.message_types_by_name['ClearPortMirrorRequest'] = _CLEARPORTMIRRORREQUEST
DESCRIPTOR.message_types_by_name['ClearPortMirrorReply'] = _CLEARPORTMIRRORREPLY
DESCRIPTOR.message_types_by_name['SetVlanOutAclRequest'] = _SETVLANOUTACLREQUEST
DESCRIPTOR.message_types_by_name['SetVlanOutAclReply'] = _SETVLANOUTACLREPLY
DESCRIPTOR.message_types_by_name['SetPortAclRequest'] = _SETPORTACLREQUEST
DESCRIPTOR.message_types_by_name['SetPortAclReply'] = _SETPORTACLREPLY
DESCRIPTOR.message_types_by_name['AddPortAclRequest'] = _ADDPORTACLREQUEST
DESCRIPTOR.message_types_by_name['AddPortAclReply'] = _ADDPORTACLREPLY
DESCRIPTOR.message_types_by_name['RemovePortAclRequest'] = _REMOVEPORTACLREQUEST
DESCRIPTOR.message_types_by_name['RemovePortAclReply'] = _REMOVEPORTACLREPLY
DESCRIPTOR.message_types_by_name['SetInterface'] = _SETINTERFACE
DESCRIPTOR.message_types_by_name['SetDpInterfaces'] = _SETDPINTERFACES
DESCRIPTOR.message_types_by_name['SetDpInterfacesRequest'] = _SETDPINTERFACESREQUEST
DESCRIPTOR.message_types_by_name['SetDpInterfacesReply'] = _SETDPINTERFACESREPLY
DESCRIPTOR.message_types_by_name['GetDpInfoRequest'] = _GETDPINFOREQUEST
DESCRIPTOR.message_types_by_name['InterfaceInfo'] = _INTERFACEINFO
DESCRIPTOR.message_types_by_name['DpInfo'] = _DPINFO
DESCRIPTOR.message_types_by_name['GetDpInfoReply'] = _GETDPINFOREPLY
DESCRIPTOR.message_types_by_name['DelDpInterfacesRequest'] = _DELDPINTERFACESREQUEST
DESCRIPTOR.message_types_by_name['DelDpInterfacesReply'] = _DELDPINTERFACESREPLY
DESCRIPTOR.message_types_by_name['DelDpsRequest'] = _DELDPSREQUEST
DESCRIPTOR.message_types_by_name['DelDpsReply'] = _DELDPSREPLY
DESCRIPTOR.message_types_by_name['GetDpNamesRequest'] = _GETDPNAMESREQUEST
DESCRIPTOR.message_types_by_name['GetDpNamesReply'] = _GETDPNAMESREPLY
DESCRIPTOR.message_types_by_name['GetDpIDsRequest'] = _GETDPIDSREQUEST
DESCRIPTOR.message_types_by_name['GetDpIDsReply'] = _GETDPIDSREPLY
DESCRIPTOR.message_types_by_name['GetAclNamesRequest'] = _GETACLNAMESREQUEST
DESCRIPTOR.message_types_by_name['GetAclNamesReply'] = _GETACLNAMESREPLY
DESCRIPTOR.message_types_by_name['SetDp'] = _SETDP
DESCRIPTOR.message_types_by_name['SetDpsRequest'] = _SETDPSREQUEST
DESCRIPTOR.message_types_by_name['SetDpsReply'] = _SETDPSREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetConfigFileRequest = _reflection.GeneratedProtocolMessageType('GetConfigFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGFILEREQUEST,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.GetConfigFileRequest)
  })
_sym_db.RegisterMessage(GetConfigFileRequest)

GetConfigFileReply = _reflection.GeneratedProtocolMessageType('GetConfigFileReply', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGFILEREPLY,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.GetConfigFileReply)
  })
_sym_db.RegisterMessage(GetConfigFileReply)

SetConfigFileRequest = _reflection.GeneratedProtocolMessageType('SetConfigFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIGFILEREQUEST,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.SetConfigFileRequest)
  })
_sym_db.RegisterMessage(SetConfigFileRequest)

SetConfigFileReply = _reflection.GeneratedProtocolMessageType('SetConfigFileReply', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIGFILEREPLY,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.SetConfigFileReply)
  })
_sym_db.RegisterMessage(SetConfigFileReply)

DelConfigFromFileRequest = _reflection.GeneratedProtocolMessageType('DelConfigFromFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELCONFIGFROMFILEREQUEST,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.DelConfigFromFileRequest)
  })
_sym_db.RegisterMessage(DelConfigFromFileRequest)

DelConfigFromFileReply = _reflection.GeneratedProtocolMessageType('DelConfigFromFileReply', (_message.Message,), {
  'DESCRIPTOR' : _DELCONFIGFROMFILEREPLY,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.DelConfigFromFileReply)
  })
_sym_db.RegisterMessage(DelConfigFromFileReply)

SetRemoteMirrorPortRequest = _reflection.GeneratedProtocolMessageType('SetRemoteMirrorPortRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETREMOTEMIRRORPORTREQUEST,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.SetRemoteMirrorPortRequest)
  })
_sym_db.RegisterMessage(SetRemoteMirrorPortRequest)

SetRemoteMirrorPortReply = _reflection.GeneratedProtocolMessageType('SetRemoteMirrorPortReply', (_message.Message,), {
  'DESCRIPTOR' : _SETREMOTEMIRRORPORTREPLY,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.SetRemoteMirrorPortReply)
  })
_sym_db.RegisterMessage(SetRemoteMirrorPortReply)

AddPortMirrorRequest = _reflection.GeneratedProtocolMessageType('AddPortMirrorRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDPORTMIRRORREQUEST,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.AddPortMirrorRequest)
  })
_sym_db.RegisterMessage(AddPortMirrorRequest)

AddPortMirrorReply = _reflection.GeneratedProtocolMessageType('AddPortMirrorReply', (_message.Message,), {
  'DESCRIPTOR' : _ADDPORTMIRRORREPLY,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.AddPortMirrorReply)
  })
_sym_db.RegisterMessage(AddPortMirrorReply)

MakeCoprocessorPortRequest = _reflection.GeneratedProtocolMessageType('MakeCoprocessorPortRequest', (_message.Message,), {
  'DESCRIPTOR' : _MAKECOPROCESSORPORTREQUEST,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.MakeCoprocessorPortRequest)
  })
_sym_db.RegisterMessage(MakeCoprocessorPortRequest)

MakeCoprocessorPortReply = _reflection.GeneratedProtocolMessageType('MakeCoprocessorPortReply', (_message.Message,), {
  'DESCRIPTOR' : _MAKECOPROCESSORPORTREPLY,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.MakeCoprocessorPortReply)
  })
_sym_db.RegisterMessage(MakeCoprocessorPortReply)

RemovePortMirrorRequest = _reflection.GeneratedProtocolMessageType('RemovePortMirrorRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPORTMIRRORREQUEST,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.RemovePortMirrorRequest)
  })
_sym_db.RegisterMessage(RemovePortMirrorRequest)

RemovePortMirrorReply = _reflection.GeneratedProtocolMessageType('RemovePortMirrorReply', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPORTMIRRORREPLY,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.RemovePortMirrorReply)
  })
_sym_db.RegisterMessage(RemovePortMirrorReply)

ClearPortMirrorRequest = _reflection.GeneratedProtocolMessageType('ClearPortMirrorRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLEARPORTMIRRORREQUEST,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.ClearPortMirrorRequest)
  })
_sym_db.RegisterMessage(ClearPortMirrorRequest)

ClearPortMirrorReply = _reflection.GeneratedProtocolMessageType('ClearPortMirrorReply', (_message.Message,), {
  'DESCRIPTOR' : _CLEARPORTMIRRORREPLY,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.ClearPortMirrorReply)
  })
_sym_db.RegisterMessage(ClearPortMirrorReply)

SetVlanOutAclRequest = _reflection.GeneratedProtocolMessageType('SetVlanOutAclRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETVLANOUTACLREQUEST,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.SetVlanOutAclRequest)
  })
_sym_db.RegisterMessage(SetVlanOutAclRequest)

SetVlanOutAclReply = _reflection.GeneratedProtocolMessageType('SetVlanOutAclReply', (_message.Message,), {
  'DESCRIPTOR' : _SETVLANOUTACLREPLY,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.SetVlanOutAclReply)
  })
_sym_db.RegisterMessage(SetVlanOutAclReply)

SetPortAclRequest = _reflection.GeneratedProtocolMessageType('SetPortAclRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETPORTACLREQUEST,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.SetPortAclRequest)
  })
_sym_db.RegisterMessage(SetPortAclRequest)

SetPortAclReply = _reflection.GeneratedProtocolMessageType('SetPortAclReply', (_message.Message,), {
  'DESCRIPTOR' : _SETPORTACLREPLY,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.SetPortAclReply)
  })
_sym_db.RegisterMessage(SetPortAclReply)

AddPortAclRequest = _reflection.GeneratedProtocolMessageType('AddPortAclRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDPORTACLREQUEST,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.AddPortAclRequest)
  })
_sym_db.RegisterMessage(AddPortAclRequest)

AddPortAclReply = _reflection.GeneratedProtocolMessageType('AddPortAclReply', (_message.Message,), {
  'DESCRIPTOR' : _ADDPORTACLREPLY,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.AddPortAclReply)
  })
_sym_db.RegisterMessage(AddPortAclReply)

RemovePortAclRequest = _reflection.GeneratedProtocolMessageType('RemovePortAclRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPORTACLREQUEST,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.RemovePortAclRequest)
  })
_sym_db.RegisterMessage(RemovePortAclRequest)

RemovePortAclReply = _reflection.GeneratedProtocolMessageType('RemovePortAclReply', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPORTACLREPLY,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.RemovePortAclReply)
  })
_sym_db.RegisterMessage(RemovePortAclReply)

SetInterface = _reflection.GeneratedProtocolMessageType('SetInterface', (_message.Message,), {
  'DESCRIPTOR' : _SETINTERFACE,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.SetInterface)
  })
_sym_db.RegisterMessage(SetInterface)

SetDpInterfaces = _reflection.GeneratedProtocolMessageType('SetDpInterfaces', (_message.Message,), {
  'DESCRIPTOR' : _SETDPINTERFACES,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.SetDpInterfaces)
  })
_sym_db.RegisterMessage(SetDpInterfaces)

SetDpInterfacesRequest = _reflection.GeneratedProtocolMessageType('SetDpInterfacesRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETDPINTERFACESREQUEST,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.SetDpInterfacesRequest)
  })
_sym_db.RegisterMessage(SetDpInterfacesRequest)

SetDpInterfacesReply = _reflection.GeneratedProtocolMessageType('SetDpInterfacesReply', (_message.Message,), {
  'DESCRIPTOR' : _SETDPINTERFACESREPLY,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.SetDpInterfacesReply)
  })
_sym_db.RegisterMessage(SetDpInterfacesReply)

GetDpInfoRequest = _reflection.GeneratedProtocolMessageType('GetDpInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDPINFOREQUEST,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.GetDpInfoRequest)
  })
_sym_db.RegisterMessage(GetDpInfoRequest)

InterfaceInfo = _reflection.GeneratedProtocolMessageType('InterfaceInfo', (_message.Message,), {
  'DESCRIPTOR' : _INTERFACEINFO,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.InterfaceInfo)
  })
_sym_db.RegisterMessage(InterfaceInfo)

DpInfo = _reflection.GeneratedProtocolMessageType('DpInfo', (_message.Message,), {
  'DESCRIPTOR' : _DPINFO,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.DpInfo)
  })
_sym_db.RegisterMessage(DpInfo)

GetDpInfoReply = _reflection.GeneratedProtocolMessageType('GetDpInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _GETDPINFOREPLY,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.GetDpInfoReply)
  })
_sym_db.RegisterMessage(GetDpInfoReply)

DelDpInterfacesRequest = _reflection.GeneratedProtocolMessageType('DelDpInterfacesRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELDPINTERFACESREQUEST,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.DelDpInterfacesRequest)
  })
_sym_db.RegisterMessage(DelDpInterfacesRequest)

DelDpInterfacesReply = _reflection.GeneratedProtocolMessageType('DelDpInterfacesReply', (_message.Message,), {
  'DESCRIPTOR' : _DELDPINTERFACESREPLY,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.DelDpInterfacesReply)
  })
_sym_db.RegisterMessage(DelDpInterfacesReply)

DelDpsRequest = _reflection.GeneratedProtocolMessageType('DelDpsRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELDPSREQUEST,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.DelDpsRequest)
  })
_sym_db.RegisterMessage(DelDpsRequest)

DelDpsReply = _reflection.GeneratedProtocolMessageType('DelDpsReply', (_message.Message,), {
  'DESCRIPTOR' : _DELDPSREPLY,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.DelDpsReply)
  })
_sym_db.RegisterMessage(DelDpsReply)

GetDpNamesRequest = _reflection.GeneratedProtocolMessageType('GetDpNamesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDPNAMESREQUEST,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.GetDpNamesRequest)
  })
_sym_db.RegisterMessage(GetDpNamesRequest)

GetDpNamesReply = _reflection.GeneratedProtocolMessageType('GetDpNamesReply', (_message.Message,), {
  'DESCRIPTOR' : _GETDPNAMESREPLY,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.GetDpNamesReply)
  })
_sym_db.RegisterMessage(GetDpNamesReply)

GetDpIDsRequest = _reflection.GeneratedProtocolMessageType('GetDpIDsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDPIDSREQUEST,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.GetDpIDsRequest)
  })
_sym_db.RegisterMessage(GetDpIDsRequest)

GetDpIDsReply = _reflection.GeneratedProtocolMessageType('GetDpIDsReply', (_message.Message,), {
  'DESCRIPTOR' : _GETDPIDSREPLY,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.GetDpIDsReply)
  })
_sym_db.RegisterMessage(GetDpIDsReply)

GetAclNamesRequest = _reflection.GeneratedProtocolMessageType('GetAclNamesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACLNAMESREQUEST,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.GetAclNamesRequest)
  })
_sym_db.RegisterMessage(GetAclNamesRequest)

GetAclNamesReply = _reflection.GeneratedProtocolMessageType('GetAclNamesReply', (_message.Message,), {
  'DESCRIPTOR' : _GETACLNAMESREPLY,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.GetAclNamesReply)
  })
_sym_db.RegisterMessage(GetAclNamesReply)

SetDp = _reflection.GeneratedProtocolMessageType('SetDp', (_message.Message,), {
  'DESCRIPTOR' : _SETDP,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.SetDp)
  })
_sym_db.RegisterMessage(SetDp)

SetDpsRequest = _reflection.GeneratedProtocolMessageType('SetDpsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETDPSREQUEST,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.SetDpsRequest)
  })
_sym_db.RegisterMessage(SetDpsRequest)

SetDpsReply = _reflection.GeneratedProtocolMessageType('SetDpsReply', (_message.Message,), {
  'DESCRIPTOR' : _SETDPSREPLY,
  '__module__' : 'faucetconfrpc.faucetconfrpc_pb2'
  # @@protoc_insertion_point(class_scope:faucetconfserver.SetDpsReply)
  })
_sym_db.RegisterMessage(SetDpsReply)


DESCRIPTOR._options = None

_FAUCETCONFSERVER = _descriptor.ServiceDescriptor(
  name='FaucetConfServer',
  full_name='faucetconfserver.FaucetConfServer',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2420,
  serialized_end=4351,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetConfigFile',
    full_name='faucetconfserver.FaucetConfServer.GetConfigFile',
    index=0,
    containing_service=None,
    input_type=_GETCONFIGFILEREQUEST,
    output_type=_GETCONFIGFILEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfigFile',
    full_name='faucetconfserver.FaucetConfServer.SetConfigFile',
    index=1,
    containing_service=None,
    input_type=_SETCONFIGFILEREQUEST,
    output_type=_SETCONFIGFILEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DelConfigFromFile',
    full_name='faucetconfserver.FaucetConfServer.DelConfigFromFile',
    index=2,
    containing_service=None,
    input_type=_DELCONFIGFROMFILEREQUEST,
    output_type=_DELCONFIGFROMFILEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddPortMirror',
    full_name='faucetconfserver.FaucetConfServer.AddPortMirror',
    index=3,
    containing_service=None,
    input_type=_ADDPORTMIRRORREQUEST,
    output_type=_ADDPORTMIRRORREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RemovePortMirror',
    full_name='faucetconfserver.FaucetConfServer.RemovePortMirror',
    index=4,
    containing_service=None,
    input_type=_REMOVEPORTMIRRORREQUEST,
    output_type=_REMOVEPORTMIRRORREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ClearPortMirror',
    full_name='faucetconfserver.FaucetConfServer.ClearPortMirror',
    index=5,
    containing_service=None,
    input_type=_CLEARPORTMIRRORREQUEST,
    output_type=_CLEARPORTMIRRORREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddPortAcl',
    full_name='faucetconfserver.FaucetConfServer.AddPortAcl',
    index=6,
    containing_service=None,
    input_type=_ADDPORTACLREQUEST,
    output_type=_ADDPORTACLREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RemovePortAcl',
    full_name='faucetconfserver.FaucetConfServer.RemovePortAcl',
    index=7,
    containing_service=None,
    input_type=_REMOVEPORTACLREQUEST,
    output_type=_REMOVEPORTACLREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetPortAcl',
    full_name='faucetconfserver.FaucetConfServer.SetPortAcl',
    index=8,
    containing_service=None,
    input_type=_SETPORTACLREQUEST,
    output_type=_SETPORTACLREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetDpInterfaces',
    full_name='faucetconfserver.FaucetConfServer.SetDpInterfaces',
    index=9,
    containing_service=None,
    input_type=_SETDPINTERFACESREQUEST,
    output_type=_SETDPINTERFACESREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetDpInfo',
    full_name='faucetconfserver.FaucetConfServer.GetDpInfo',
    index=10,
    containing_service=None,
    input_type=_GETDPINFOREQUEST,
    output_type=_GETDPINFOREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DelDpInterfaces',
    full_name='faucetconfserver.FaucetConfServer.DelDpInterfaces',
    index=11,
    containing_service=None,
    input_type=_DELDPINTERFACESREQUEST,
    output_type=_DELDPINTERFACESREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DelDps',
    full_name='faucetconfserver.FaucetConfServer.DelDps',
    index=12,
    containing_service=None,
    input_type=_DELDPSREQUEST,
    output_type=_DELDPSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetRemoteMirrorPort',
    full_name='faucetconfserver.FaucetConfServer.SetRemoteMirrorPort',
    index=13,
    containing_service=None,
    input_type=_SETREMOTEMIRRORPORTREQUEST,
    output_type=_SETREMOTEMIRRORPORTREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetDpNames',
    full_name='faucetconfserver.FaucetConfServer.GetDpNames',
    index=14,
    containing_service=None,
    input_type=_GETDPNAMESREQUEST,
    output_type=_GETDPNAMESREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetDpIDs',
    full_name='faucetconfserver.FaucetConfServer.GetDpIDs',
    index=15,
    containing_service=None,
    input_type=_GETDPIDSREQUEST,
    output_type=_GETDPIDSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetAclNames',
    full_name='faucetconfserver.FaucetConfServer.GetAclNames',
    index=16,
    containing_service=None,
    input_type=_GETACLNAMESREQUEST,
    output_type=_GETACLNAMESREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetDps',
    full_name='faucetconfserver.FaucetConfServer.SetDps',
    index=17,
    containing_service=None,
    input_type=_SETDPSREQUEST,
    output_type=_SETDPSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='MakeCoprocessorPort',
    full_name='faucetconfserver.FaucetConfServer.MakeCoprocessorPort',
    index=18,
    containing_service=None,
    input_type=_MAKECOPROCESSORPORTREQUEST,
    output_type=_MAKECOPROCESSORPORTREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetVlanOutAcl',
    full_name='faucetconfserver.FaucetConfServer.SetVlanOutAcl',
    index=19,
    containing_service=None,
    input_type=_SETVLANOUTACLREQUEST,
    output_type=_SETVLANOUTACLREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_FAUCETCONFSERVER)

DESCRIPTOR.services_by_name['FaucetConfServer'] = _FAUCETCONFSERVER

# @@protoc_insertion_point(module_scope)



#!/usr/bin/python3

"""Manage FAUCET config files via RPC (client)."""

import argparse
import inspect
from faucetconfrpc.faucetconfrpc_client_lib import FaucetConfRpcClient
from faucetconfrpc.faucetconfrpc_server import yaml_load, yaml_dump


class ClientError(Exception):
    """Exceptions for client."""


def get_attributes(cls):
    """Get available RPCs via attrs"""
    boring = dir(type('dummy', (object,), {}))
    return [item for item in inspect.getmembers(cls) if item[0] not in boring]


def yaml_sanity():
    """Ensure YAML libraries present."""
    test_dict = {'test': 'value'}
    test_yaml = yaml_dump(test_dict)
    assert yaml_load(test_yaml) == test_dict


def main():
    """Instantiate client and call it."""
    yaml_sanity()
    parser = argparse.ArgumentParser()
    parser.add_argument(
        '--key', help='client private key', action='store',
        default='client.key')
    parser.add_argument(
        '--cert', help='client public cert', action='store',
        default='client.crt')
    parser.add_argument(
        '--cacert', help='CA public cert', action='store',
        default='ca.crt')
    parser.add_argument(
        '--port', help='port of rpc server', action='store',
        default=59999, type=int)
    parser.add_argument(
        '--host', help='host address of rpc server',
        default='localhost')
    parser.add_argument(
        'commands', type=str, nargs='+',
        help='rpc commands')
    args = parser.parse_args()
    server_addr = '%s:%u' % (args.host, args.port)
    client = FaucetConfRpcClient(args.key, args.cert, args.cacert, server_addr)

    if args.commands[0] == 'list_rpcs':
        attributes = get_attributes(client)
        for attribute in attributes:
            if not attribute[0].startswith('_'):
                print(attribute[0])
        return

    command = getattr(client, args.commands[0], None)
    if not command:
        raise ClientError('no such rpc: %s' % args.commands[0])
    command_args = {}
    for args in args.commands[1:]:
        arg, val = args.split('=')
        if val.lower() == 'true':
            val = True
        elif val.lower() == 'false':
            val = False
        command_args[arg] = val
    print(command(**command_args))


if __name__ == '__main__':
    main()
